Contact UCSB
Description: THE CONTACT PAGE provides site visitors the opportunity to submit questions and comments about the University or this site.
Keywords: UCSB, university, Santa Barbara, contact, feedback, email, contribute, submit comments, get in touch

HOME INDEX: A B C D E F G H I J K L M N O P Q R S T U V W X Y Z # PEOPLE | SEARCH
Our Mailing Address UC Santa Barbara Santa Barbara, CA 93106
Our Phone Number (805) 893-8000
Need to contact a person or a department? For the mailing address, phone number, or e-mail address for a student, faculty, staff, or department, please go directly to the People Finder.
Want fast answers? Our web site offers you the quickest ways to get answers to questions about UCSB:
Check our Frequently Asked Questions for basic information about admissions, academic departments, financial aid, campus tours, academic calendar, transcripts, and more. For the general catalog, brochures, and other school publications, visit the admissions publications page. The A-Z index has links to more than 500 campus web sites. Our Search function is fast and accurate.
For other questions or comments Please fill out the form in the box below. All fields are required.
I have a question about: General Catalog, brochures, and other publications Undergraduate Admissions PRE-application Undergraduate Admissions POST-application Graduate Admissions Alumni Association Campus Tours GauchoNet GOLD for Students Student Records Transferring to UCSB Transcript Web accessibility Web site suggestion Web site problem reporting Other
Question or Comment: 1000 character maximum
Your name:
Your e-mail address:
Copyright © The Regents of the University of California, All Rights Reserved. UC Santa Barbara, Santa Barbara, CA 93106 • (805) 893-8000